Enable checkstyle rule to verify method names

Enabled checkstyle rule "MethodName" which checks
if method names adhere to a naming convention and
fixed the violations it found.

Change-Id: I87448a1fa857e78f33c42090d485bf21a8986ba7
diff --git a/src/main/java/net/onrc/onos/core/datastore/hazelcast/HZTable.java b/src/main/java/net/onrc/onos/core/datastore/hazelcast/HZTable.java
index 7b97ec0..20501bb 100644
--- a/src/main/java/net/onrc/onos/core/datastore/hazelcast/HZTable.java
+++ b/src/main/java/net/onrc/onos/core/datastore/hazelcast/HZTable.java
@@ -43,7 +43,7 @@
     }
 
     /**
      * increment version, avoiding VERSION_NONEXISTENT.
      *
      * @param version
      * @return
@@ -320,7 +320,7 @@
     }
 
     @Override
-    public long VERSION_NONEXISTENT() {
+    public long getVersionNonexistant() {
         return HZClient.VERSION_NONEXISTENT;
     }
 }
@@ -43,7 +43,7 @@
 
     /**
-     * increment version, avoiding VERSION_NONEXISTENT.
+     * increment version, avoiding versionNonexistant.
      *
      * @param version